@@ -416,8 +416,7 @@ class SeedHypervisorHostUpgrade(KayobeAnsibleMixin, VaultMixin, Command):
 
     def take_action(self, parsed_args):
         self.app.LOG.debug("Upgrading seed hypervisor host services")
-        playbooks = _build_playbook_list(
-            "kayobe-target-venv", "kolla-target-venv")
+        playbooks = _build_playbook_list("kayobe-target-venv")
         self.run_kayobe_playbooks(parsed_args, playbooks,
                                   limit="seed-hypervisor")
 
@@ -711,7 +710,7 @@ class SeedContainerImageBuild(KayobeAnsibleMixin, VaultMixin, Command):
             "container-image-build")
         extra_vars = {"push_images": parsed_args.push}
         if parsed_args.regex:
-            regexes = "'%s'" % " ".join(parsed_args.regex)
+            regexes = " ".join(parsed_args.regex)
             extra_vars["container_image_regexes"] = regexes
         else:
             extra_vars["container_image_sets"] = (
@@ -1357,7 +1356,7 @@ class OvercloudContainerImageBuild(KayobeAnsibleMixin, VaultMixin, Command):
             "container-image-build")
         extra_vars = {"push_images": parsed_args.push}
         if parsed_args.regex:
-            regexes = "'%s'" % " ".join(parsed_args.regex)
+            regexes = " ".join(parsed_args.regex)
             extra_vars["container_image_regexes"] = regexes
         else:
             extra_vars["container_image_sets"] = (
