@@ -87,11 +87,16 @@ def _validate_args(parsed_args, inventory_filename):
         sys.exit(1)
 
     inventory = _get_inventory_path(parsed_args, inventory_filename)
-    result = utils.is_readable_file(inventory)
+    result = utils.is_readable_dir(parsed_args.kolla_venv)
     if not result["result"]:
-        LOG.error("Kolla inventory %s is invalid: %s",
-                  inventory, result["message"])
-        sys.exit(1)
+        # NOTE(mgoddard): Previously the inventory was a file, now it is a
+        # directory to allow us to support inventory host_vars. Support both
+        # formats for now.
+        result_f = utils.is_readable_file(inventory)
+        if not result_f["result"]:
+            LOG.error("Kolla inventory %s is invalid: %s",
+                      inventory, result["message"])
+            sys.exit(1)
 
     result = utils.is_readable_dir(parsed_args.kolla_venv)
     if not result["result"]:
@@ -117,9 +122,13 @@ def build_args(parsed_args, command, inventory_filename, extra_vars=None,
                 os.path.join(parsed_args.kolla_config_path, "passwords.yml")]
     if parsed_args.kolla_extra_vars:
         for extra_var in parsed_args.kolla_extra_vars:
+            # Don't quote or escape variables passed via the kayobe -e CLI
+            # argument, to match Ansible's behaviour.
             cmd += ["-e", extra_var]
     if extra_vars:
         for extra_var_name, extra_var_value in extra_vars.items():
+            # Quote and escape variables originating within the python CLI.
+            extra_var_value = utils.quote_and_escape(extra_var_value)
             cmd += ["-e", "%s=%s" % (extra_var_name, extra_var_value)]
     if parsed_args.kolla_limit or limit:
         limits = [l for l in [parsed_args.kolla_limit, limit] if l]
