@@ -376,8 +376,6 @@ class TestCase(unittest.TestCase):
                 [
                     utils.get_data_files_path(
                         "ansible", "kayobe-target-venv.yml"),
-                    utils.get_data_files_path(
-                        "ansible", "kolla-target-venv.yml"),
                 ],
                 limit="seed-hypervisor",
             ),
@@ -749,7 +747,7 @@ class TestCase(unittest.TestCase):
                         "ansible", "container-image-build.yml")
                 ],
                 extra_vars={
-                    "container_image_regexes": "'^regex1$ ^regex2$'",
+                    "container_image_regexes": "^regex1$ ^regex2$",
                     "push_images": True,
                 }
             ),
@@ -1642,7 +1640,7 @@ class TestCase(unittest.TestCase):
                         "ansible", "container-image-build.yml")
                 ],
                 extra_vars={
-                    "container_image_regexes": "'^regex1$ ^regex2$'",
+                    "container_image_regexes": "^regex1$ ^regex2$",
                     "push_images": True,
                 }
             ),
